module EngineProject
  class Engine < ::Rails::Engine
    isolate_namespace EngineProject
  end
end
